@@ -2,6 +2,11 @@
 
 __author__ = """Santosh Panna"""
 __email__ = 'santoshpanna.sp@gmail.com'
-__version__ = '0.0.1'
+__version__ = '0.0.3.6'
 
-from .steamstorefront import SteamStoreFront
\ No newline at end of file
+import builtins
+
+from .steamstorefront import SteamStoreFront
+from .errors import InvalidArgument
+
+builtins.InvalidArgument = InvalidArgument
